/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.io;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;
import static org.junit.Assume.assumeTrue;

import java.io.File;
import java.io.IOException;

import org.apache.commons.lang3.SystemUtils;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;

/**
 * Unit tests of {@link FileSystemHelper} that runs only on Linux, mainly because we are unable to create restricted
 * folder
 * 
 * @author Marc Jambert - EBM WebSourcing
 * @author Christophe DENEUX - Linagora
 */
public class FileSystemHelperLinuxOnlyTest {

    @Rule
    public TemporaryFolder tempFolder = new TemporaryFolder();

    @Before
    public void linuxOnly() {
        org.junit.Assume.assumeTrue(SystemUtils.IS_OS_LINUX);
    }

    @Test(expected = IOException.class)
    public void testCleanRestrictedDirectory() throws IOException {

        // This unit is run only on Unix because we are unable to create a restricted folder on Windows
        assumeTrue(SystemUtils.IS_OS_LINUX);

        final File restrictedDirectory = this.tempFolder.newFolder("restricted-folder");
        assertTrue(restrictedDirectory.setReadable(false));
        assertTrue(restrictedDirectory.setWritable(false));
        try {
            FileSystemHelper.cleanDirectory(restrictedDirectory);
        } catch (final IOException e) {
            restrictedDirectory.setReadable(true);
            restrictedDirectory.setWritable(true);
            throw e;
        }
        fail("Cleaning a restricted directory isn't allowed");
    }

    @Test(expected = IOException.class)
    public void testForceDeleteRestrictedDirectory() throws IOException {

        final File restrictedDirectory = this.tempFolder.newFolder("restricted-folder");
        assertTrue(restrictedDirectory.setReadable(false));
        assertTrue(restrictedDirectory.setWritable(false));
        try {
            FileSystemHelper.forceDelete(restrictedDirectory);
        } catch (final IOException e) {
            restrictedDirectory.setReadable(true);
            restrictedDirectory.setWritable(true);
            throw e;
        }
        fail("Deleting a restricted directory isn't allowed");
    }
}
