/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.io;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URL;
import java.util.zip.ZipFile;

import org.junit.BeforeClass;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public class ZipHelperTest {
	
	private static ZipFile testArchive;
	
    @Rule
    public final TemporaryFolder temporaryFolder = new TemporaryFolder();
	

	@BeforeClass
	public static void beforeClass() throws Exception {
		URL testArchiveUrl = ZipHelperTest.class.getClassLoader().getResource("test.zip");
		testArchive = new ZipFile(new File(testArchiveUrl.toURI()));
	}
	
	@Test
	public void testExtractAllEntriesFromArchive() throws Exception {
        final File tempDir = this.temporaryFolder.newFolder("extract-archive-all-entries");
		ZipHelper.extractEntriesFromArchive(testArchive, "", tempDir);
		
		assertTrue(new File(tempDir, "test/file1.txt").exists());
		assertTrue(new File(tempDir, "test/file2.txt").exists());
		assertTrue(new File(tempDir, "test/3file.txt").exists());
		assertTrue(new File(tempDir, "test/emptyDir/anotherEmptyDir1").exists());
		assertTrue(new File(tempDir, "test/emptyDir/anotherEmptyDir2").exists());		
	}

	@Test
    public void testExtractOnlyAnEntryFromArchive() throws Exception {
        final File tempDir = this.temporaryFolder.newFolder("extract-archive-one-entry");
		ZipHelper.extractEntriesFromArchive(testArchive, "test/3file.txt", tempDir);

		assertTrue(!(new File(tempDir, "test/file1.txt").exists()));
		assertTrue(!(new File(tempDir, "test/file2.txt").exists()));
		assertTrue(new File(tempDir, "test/3file.txt").exists());
		assertTrue(!(new File(tempDir, "test/emptyDir/anotherEmptyDir1").exists()));
		assertTrue(!(new File(tempDir, "test/emptyDir/anotherEmptyDir2").exists()));		
	}
	
	@Test
    public void testExtractEntriesStartingWithEntryNamePrefixFromArchive() throws Exception {
        final File tempDir = this.temporaryFolder.newFolder("extract-archive-all-entries-entries-from-prefix");
		ZipHelper.extractEntriesFromArchive(testArchive, "test/fi", tempDir);

		assertTrue(new File(tempDir, "test/file1.txt").exists());
		assertTrue(new File(tempDir, "test/file2.txt").exists());
		assertTrue(!(new File(tempDir, "test/3file.txt").exists()));
		assertTrue(!(new File(tempDir, "test/emptyDir/anotherEmptyDir1").exists()));
		assertTrue(!(new File(tempDir, "test/emptyDir/anotherEmptyDir2").exists()));		
	}
	
	@Test
	public void testExtractEntriesFromArchiveContainingEmptyDir() throws Exception {
        final File tempDir = this.temporaryFolder.newFolder("extract-archive-with-empty-dir");
		ZipHelper.extractEntriesFromArchive(testArchive, "test/emptyDir", tempDir);

		assertTrue(!(new File(tempDir, "test/file1.txt").exists()));
		assertTrue(!(new File(tempDir, "test/file2.txt").exists()));
		assertTrue(!(new File(tempDir, "test/3file.txt").exists()));
		assertTrue(new File(tempDir, "test/emptyDir/anotherEmptyDir1").exists());
		assertTrue(new File(tempDir, "test/emptyDir/anotherEmptyDir2").exists());		
	}
}
